PyKED
=====

|DOI| |Travis Build Status| |Appveyor Build status| |codecov|
|Dependency Status| |Code of Conduct| |License| |Anaconda-Server Badge|

PyKED is a Python-based software package for validating and interacting
with ChemKED (Chemical Kinetics Experimental Data format) files that
describe fundamental experimental measurements of combustion phenomena.

Code of Conduct
---------------

In order to have a more open and welcoming community, PyKED adheres to a
code of conduct adapted from the `Contributor
Covenant <http://contributor-covenant.org>`__ code of conduct. The code
of conduct for PyKED is available in the GitHub Repository in the
`CODE\_OF\_CONDUCT.md <https://github.com/pr-omethe-us/PyKED/blob/master/CODE_OF_CONDUCT.md>`__
file.

Please adhere to this code of conduct in any interactions you have in
the PyKED community. It is strictly enforced on all official PyKED
repositories, websites, and resources. If you encounter someone
violating these terms, please let a maintainer
([@kyleniemeyer](https://github.com/kyleniemeyer),
[@bryanwweber](https://github.com/bryanwweber), or via email at
chemked@googlegroups.com) know and we will address it as soon as
possible.

License
-------

PyKED is released under the BSD-3 clause license, see LICENSE for
details.

If you use this package as part of a scholarly work, please refer to
CITATION.md for guidance on citing this resource.

Change Log
==========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <http://keepachangelog.com/>`__
and this project adheres to `Semantic
Versioning <http://semver.org/>`__.

`Unreleased <https://github.com/pr-omethe-us/PyKED/compare/v0.1.6...HEAD>`__
----------------------------------------------------------------------------

Added
~~~~~

Fixed
~~~~~

Changed
~~~~~~~

`0.1.6 <https://github.com/pr-omethe-us/PyKED/compare/v0.1.5...v0.1.6>`__ - 2017-07-17
--------------------------------------------------------------------------------------

Added
~~~~~

-  Added logo files to repo
-  Added ``first_stage_ignition_delay``, ``compressed_pressure``, and
   ``compressed_temperature`` as properties

Fixed
~~~~~

Changed
~~~~~~~

-  Added Zenodo collection DOI to CITATION.md

`0.1.5 <https://github.com/pr-omethe-us/PyKED/compare/v0.1.4...v0.1.5>`__ - 2017-05-22
--------------------------------------------------------------------------------------

Added
~~~~~

-  Schema can now be split into multiple files via ``!include``
   directive

Fixed
~~~~~

-  Remove Python 2.7 classifier from ``setup.py``
-  DataFrame output for datapoints lists with multiple compositions
   (i.e., a species not in all compositions)

Changed
~~~~~~~

-  Improved tests with no internet
-  Improved tests with no warning

`0.1.4 <https://github.com/pr-omethe-us/PyKED/compare/v0.1.3...v0.1.4>`__ - 2017-04-21
--------------------------------------------------------------------------------------

Added
~~~~~

-  Add ``skip_validation`` keyword argument to the ``ChemKED``
   initializer

Removed
~~~~~~~

-  Python 2.7 support is removed again

`0.1.3 <https://github.com/pr-omethe-us/PyKED/compare/v0.1.2...v0.1.3>`__ - 2017-04-13
--------------------------------------------------------------------------------------

Added
~~~~~

-  Add back Python 2.7 support
-  Add Appveyor builds for Windows conda packages

`0.1.2 <https://github.com/pr-omethe-us/PyKED/compare/v0.1.1...v0.1.2>`__ - 2017-04-13
--------------------------------------------------------------------------------------

Added
~~~~~

-  Tests of the composition uncertainty in the DataPoint
-  Tests of the values in the references
-  Packaging for conda and PyPI
-  Add Anaconda-Server badge to README

Changed
~~~~~~~

-  All fixed DOIs in CITATION.md are now specified with placeholders

`0.1.1 <https://github.com/pr-omethe-us/PyKED/compare/v0.1.0...v0.1.1>`__ - 2017-04-02
--------------------------------------------------------------------------------------

Added
~~~~~

-  Added Zenodo DOI badge to README
-  Added CITATION file, and mention of license to README

Fixed
~~~~~

-  Fixed chemked-version bug in schema introduced in 0.1.0

`0.1.0 <https://github.com/pr-omethe-us/PyKED/compare/75ecf67766a0be2a80e2377391fd9eca420f152c...v0.1.0>`__ - 2017-04-02
------------------------------------------------------------------------------------------------------------------------

Added
~~~~~

-  First minor release of PyKED, supporting autoignition experiments.
-  Basic API documentation is available via
   https://pr-omethe-us.github.io/PyKED/

Citation of PyKED
=================

|DOI|

To cite PyKED in a scholarly article, please use

    K. E. Niemeyer and B. W. Weber. (2017) PyKED v0.1.6 [software].
    Zenodo. https://doi.org/10.5281/zenodo.597935

A BibTeX entry for LaTeX users is

.. code:: tex

    @misc{PyKED,
        author = {Kyle E Niemeyer and Bryan W Weber},
        year = 2017,
        title = {PyKED v0.1.6},
        doi = {10.5281/zenodo.597935},
        url = {https://github.com/pr-omethe-us/PyKED},
    }

In both cases, please update the entry with the version used. The DOI
for the latest version is given in the badge at the top, or alternately
https://doi.org/10.5281/zenodo.597935 will take you to the latest
version (and generally represents all versions). If you would like to
cite a specific, older version, the DOIs for each release are:

-  v0.1.5:
   `10.5281/zenodo.582345 <https://doi.org/10.5281/zenodo.582345>`__
-  v0.1.4:
   `10.5281/zenodo.582338 <https://doi.org/10.5281/zenodo.582338>`__
-  v0.1.3:
   `10.5281/zenodo.439720 <https://doi.org/10.5281/zenodo.546143>`__
-  v0.1.2:
   `10.5281/zenodo.439720 <https://doi.org/10.5281/zenodo.546141>`__
-  v0.1.1:
   `10.5281/zenodo.439720 <https://doi.org/10.5281/zenodo.439720>`__
-  v0.1.0:
   `10.5281/zenodo.439716 <https://doi.org/10.5281/zenodo.439716>`__

.. |DOI| image:: https://zenodo.org/badge/66023863.svg
   :target: https://zenodo.org/badge/latestdoi/66023863
.. |Travis Build Status| image:: https://travis-ci.org/pr-omethe-us/PyKED.svg?branch=master
   :target: https://travis-ci.org/pr-omethe-us/PyKED
.. |Appveyor Build status| image:: https://ci.appveyor.com/api/projects/status/0paym07iygcfwoy7?svg=true
   :target: https://ci.appveyor.com/project/Prometheus/pyked
.. |codecov| image:: https://codecov.io/gh/pr-omethe-us/PyKED/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/pr-omethe-us/PyKED
.. |Dependency Status| image:: https://dependencyci.com/github/pr-omethe-us/PyKED/badge
   :target: https://dependencyci.com/github/pr-omethe-us/PyKED
.. |Code of Conduct| image:: https://img.shields.io/badge/code%20of%20conduct-contributor%20covenant-green.svg
   :target: http://contributor-covenant.org/version/1/4/
.. |License| image:: https://img.shields.io/badge/license-BSD-blue.svg
   :target: https://opensource.org/licenses/BSD-3-Clause
.. |Anaconda-Server Badge| image:: https://anaconda.org/pr-omethe-us/pyked/badges/version.svg
   :target: https://anaconda.org/pr-omethe-us/pyked
